@@ -1,6 +1,6 @@
 package Statocles::Command;
 # ABSTRACT: The statocles command-line interface
-$Statocles::Command::VERSION = '0.061';
+$Statocles::Command::VERSION = '0.062';
 use Statocles::Base 'Class';
 use Scalar::Util qw( blessed );
 use Getopt::Long qw( GetOptionsFromArray :config pass_through bundling no_auto_abbrev );
@@ -182,9 +182,12 @@ sub main {
                 return 1;
             }
 
-            $cmd->bundle_theme( $theme_name, $argv[2] );
-            say qq{Theme "$theme_name" written to "$argv[2]"};
-            say qq(Make sure to update "$opt{config}");
+            my $dest_dir = Path::Tiny->new( $argv[2] );
+            $cmd->bundle_theme( $theme_name, $dest_dir );
+            say qq{Theme "$theme_name" written to "$dest_dir"};
+            if ( !$site->theme->store->path->realpath->subsumes( $dest_dir->realpath ) ) {
+                say qq(Make sure to update "$opt{config}");
+            }
         }
     }
     else {
@@ -592,7 +595,7 @@ Statocles::Command - The statocles command-line interface
 
 =head1 VERSION
 
-version 0.061
+version 0.062
 
 =head1 SYNOPSIS
 
