@@ -1,6 +1,6 @@
 package Statocles::Document;
 # ABSTRACT: Base class for all Statocles documents
-$Statocles::Document::VERSION = '0.061';
+$Statocles::Document::VERSION = '0.062';
 use Statocles::Base 'Class';
 use Statocles::Image;
 
@@ -118,7 +118,7 @@ Statocles::Document - Base class for all Statocles documents
 
 =head1 VERSION
 
-version 0.061
+version 0.062
 
 =head1 DESCRIPTION
 
@@ -152,7 +152,9 @@ The path to this document. This is not settable from the frontmatter.
     title: My First Post
     ---
 
-The title of this document. Used in the template and the main page title.
+The title of this document. Used in the template and the main page
+title. Any unsafe characters in the title (C<E<lt>>, C<E<gt>>, C<">, and
+C<&>) will be escaped by the template, so no HTML allowed.
 
 =head2 author
 
