@@ -1,6 +1,6 @@
 package Statocles::Page;
 # ABSTRACT: Base class for rendering objects
-$Statocles::Page::VERSION = '0.061';
+$Statocles::Page::VERSION = '0.062';
 use Statocles::Base 'Role';
 use Statocles::Template;
 
@@ -111,7 +111,7 @@ my @template_attrs = (
     isa => InstanceOf['Statocles::Template'],
     coerce => Statocles::Template->coercion,
     default => sub {
-        Statocles::Template->new( content => '<%= $content %>' ),
+        Statocles::Template->new( content => '<%= content %>' ),
     },
 );
 
@@ -183,7 +183,11 @@ sub render {
 
 
 sub links {
-    my ( $self, $name ) = @_;
+    my ( $self, $name, $add_link ) = @_;
+    if ( $add_link ) {
+        push @{ $self->_links->{ $name } }, Link->coerce( $add_link );
+        return;
+    }
     my @links = $self->_links->{ $name } ? @{ $self->_links->{ $name } } : ();
     return wantarray ? @links : $links[0];
 }
@@ -222,7 +226,7 @@ Statocles::Page - Base class for rendering objects
 
 =head1 VERSION
 
-version 0.061
+version 0.062
 
 =head1 DESCRIPTION
 
@@ -246,7 +250,9 @@ The absolute URL path to save this page to.
 
 =head2 title
 
-The title of the page.
+The title of the page. Any unsafe characters in the title (C<E<lt>>,
+C<E<gt>>, C<">, and C<&>) will be escaped by the template, so no HTML
+allowed.
 
 =head2 type
 
@@ -354,10 +360,19 @@ The result of this method is cached.
 
     my @links = $page->links( $key );
     my $link = $page->links( $key );
+    $page->links( $key => $add_link );
 
-Get the links set for the given key. See L<the links attribute|/links> for some
-commonly-used keys. Returns a list of L<link objects|Statocles::Link>. In
-scalar context, returns the first link in the list.
+Get or append to the links set for the given key. See L<the links
+attribute|/links> for some commonly-used keys.
+
+If only one argument is given, returns a list of L<link
+objects|Statocles::Link>. In scalar context, returns the first link in
+the list.
+
+If two arguments are given, append the new link to the given key.
+C<$add_link> may be a URL string, a hash reference of L<link
+attributes|Statocles::Link/ATTRIBUTES>, or a L<Statocles::Link
+object|Statocles::Link>. When adding links, nothing is returned.
 
 =head2 images
 
