@@ -1,6 +1,6 @@
 package Statocles::Page::Document;
 # ABSTRACT: Render document objects into HTML
-$Statocles::Page::Document::VERSION = '0.061';
+$Statocles::Page::Document::VERSION = '0.062';
 use Statocles::Base 'Class';
 with 'Statocles::Page';
 use Statocles::Template;
@@ -56,7 +56,7 @@ has '+_images' => (
 sub _render_content_template {
     my ( $self, $content, $vars ) = @_;
     my $tmpl = $self->site->theme->build_template( $self->path, $content );
-    my $rendered = $tmpl->render( %$vars, $self->vars, self => $self->document );
+    my $rendered = $tmpl->render( %$vars, $self->vars, self => $self->document, page => $self );
     return $rendered;
 }
 
@@ -140,7 +140,7 @@ Statocles::Page::Document - Render document objects into HTML
 
 =head1 VERSION
 
-version 0.061
+version 0.062
 
 =head1 DESCRIPTION
 
