@@ -1,7 +1,8 @@
 package Statocles::Plugin::HTMLLint;
 # ABSTRACT: Check HTML for common errors and issues
-$Statocles::Plugin::HTMLLint::VERSION = '0.061';
+$Statocles::Plugin::HTMLLint::VERSION = '0.062';
 use Statocles::Base 'Class';
+with 'Statocles::Plugin';
 BEGIN {
     eval { require HTML::Lint::Pluggable; HTML::Lint::Pluggable->VERSION( 0.06 ); 1 }
         or die "Error loading Statocles::Plugin::HTMLLint. To use this plugin, install HTML::Lint::Pluggable";
@@ -39,6 +40,12 @@ sub check_pages {
     }
 }
 
+
+sub register {
+    my ( $self, $site ) = @_;
+    $site->on( build => sub { $self->check_pages( @_ ) } );
+}
+
 1;
 
 __END__
@@ -51,17 +58,17 @@ Statocles::Plugin::HTMLLint - Check HTML for common errors and issues
 
 =head1 VERSION
 
-version 0.061
+version 0.062
 
 =head1 SYNOPSIS
 
     # site.yml
     site:
         class: Statocles::Site
-        on:
-            - build:
-                $class: Statocles::Plugin::HTMLLint
-                $method: check_pages
+        args:
+            plugins:
+                lint:
+                    $class: Statocles::Plugin::HTMLLint
 
 =head1 DESCRIPTION
 
@@ -84,6 +91,10 @@ plugins good for HTML5: 'HTML5' and 'TinyEntitesEscapeRule'
 Check the pages inside the given
 L<Statocles::Event::Pages|Statocles::Event::Pages> event.
 
+=head2 register
+
+Register this plugin to install its event handlers. Called automatically.
+
 =head1 AUTHOR
 
 Doug Bell <preaction@cpan.org>
