@@ -1,7 +1,8 @@
 package Statocles::Plugin::LinkCheck;
 # ABSTRACT: Check links and images for validity during build
-$Statocles::Plugin::LinkCheck::VERSION = '0.061';
+$Statocles::Plugin::LinkCheck::VERSION = '0.062';
 use Statocles::Base 'Class';
+with 'Statocles::Plugin';
 use Mojo::DOM;
 use Mojo::Util qw( url_escape url_unescape );
 
@@ -51,6 +52,12 @@ sub check_pages {
 
 }
 
+
+sub register {
+    my ( $self, $site ) = @_;
+    $site->on( build => sub { $self->check_pages( @_ ) } );
+}
+
 1;
 
 __END__
@@ -63,17 +70,17 @@ Statocles::Plugin::LinkCheck - Check links and images for validity during build
 
 =head1 VERSION
 
-version 0.061
+version 0.062
 
 =head1 SYNOPSIS
 
     # site.yml
     site:
         class: Statocles::Site
-        on:
-            - build:
-                $class: Statocles::Plugin::LinkCheck
-                $method: check_pages
+        args:
+            plugins:
+                link_check:
+                    $class: Statocles::Plugin::LinkCheck
 
 =head1 DESCRIPTION
 
@@ -101,6 +108,10 @@ For example:
 Check the pages inside the given
 L<Statocles::Event::Pages|Statocles::Event::Pages> event.
 
+=head2 register
+
+Register this plugin to install its event handlers. Called automatically.
+
 =head1 AUTHOR
 
 Doug Bell <preaction@cpan.org>
