@@ -1,6 +1,6 @@
 package Statocles::Site;
 # ABSTRACT: An entire, configured website
-$Statocles::Site::VERSION = '0.061';
+$Statocles::Site::VERSION = '0.062';
 use Statocles::Base 'Class', 'Emitter';
 use Scalar::Util qw( blessed );
 use Text::Markdown;
@@ -42,6 +42,13 @@ has apps => (
 );
 
 
+has plugins => (
+    is => 'ro',
+    isa => HashRef[ConsumerOf['Statocles::Plugin']],
+    default => sub { {} },
+);
+
+
 has index => (
     is => 'ro',
     isa => Str,
@@ -135,6 +142,9 @@ sub BUILD {
     for my $app ( values %{ $self->apps } ) {
         $app->site( $self );
     }
+    for my $plugin ( values %{ $self->plugins } ) {
+        $plugin->register( $self );
+    }
 }
 
 
@@ -376,7 +386,7 @@ Statocles::Site - An entire, configured website
 
 =head1 VERSION
 
-version 0.061
+version 0.062
 
 =head1 SYNOPSIS
 
@@ -418,6 +428,10 @@ The L<theme|Statocles::Theme> for this site. All apps share the same theme.
 The applications in this site. Each application has a name
 that can be used later.
 
+=head2 plugins
+
+The plugins in this site. Each plugin has a name that can be used later.
+
 =head2 index
 
 The page path to use for the site index. Make sure to include the leading slash
