@@ -1,6 +1,6 @@
 package Statocles::Store;
 # ABSTRACT: The source for data documents and files
-$Statocles::Store::VERSION = '0.061';
+$Statocles::Store::VERSION = '0.062';
 use Statocles::Base 'Class';
 use Scalar::Util qw( weaken blessed );
 use Statocles::Document;
@@ -55,15 +55,29 @@ has _realpath => (
     default => sub { $_[0]->path->realpath },
 );
 
+# If true, we've already checked if this store's path exists. We need to
+# check this lazily to ensure the site is created and the logger is
+# ready to go.
+#
+# XXX: Making sure the logger is ready before the thing that needs it is
+# the entire reason that dependency injection exists. We should use the
+# container to make sure the logger is wired up with every object that
+# needs it...
+has _check_exists => (
+    is => 'rw',
+    isa => Bool,
+    lazy => 1,
+    default => sub {
+        my ( $self ) = @_;
+        if ( !$self->path->exists ) {
+            site->log->warn( sprintf qq{Store path "%s" does not exist}, $self->path );
+        }
+        return 1;
+    },
+);
+
 sub BUILD {
     my ( $self ) = @_;
-    if ( !$self->path->exists ) {
-        die sprintf "Store path '%s' does not exist", $self->path->stringify;
-    }
-    elsif ( !$self->path->is_dir ) {
-        die sprintf "Store path '%s' is not a directory", $self->path->stringify;
-    }
-
     $FILE_STORES{ $self->_realpath }++;
 }
 
@@ -78,6 +92,7 @@ sub DEMOLISH {
 
 sub read_documents {
     my ( $self ) = @_;
+    $self->_check_exists;
     my $root_path = $self->path;
     my @docs;
     my $iter = $root_path->iterator( { recurse => 1, follow_symlinks => 1 } );
@@ -235,6 +250,7 @@ sub has_file {
 
 sub find_files {
     my ( $self, %opt ) = @_;
+    $self->_check_exists;
     my $iter = $self->path->iterator({ recurse => 1 });
     return sub {
         my $path;
@@ -296,7 +312,7 @@ Statocles::Store - The source for data documents and files
 
 =head1 VERSION
 
-version 0.061
+version 0.062
 
 =head1 DESCRIPTION
 
