@@ -1,6 +1,6 @@
 package Statocles::Template;
 # ABSTRACT: A template object to pass around
-$Statocles::Template::VERSION = '0.061';
+$Statocles::Template::VERSION = '0.062';
 use Statocles::Base 'Class';
 use Mojo::Template;
 use Scalar::Util qw( blessed );
@@ -77,6 +77,19 @@ sub render {
         # Add the helper subs, like Mojolicious::Plugin::EPRenderer does
         no strict 'refs';
         no warnings 'redefine';
+
+        # Add theme helpers first, to ensure default helpers do not get
+        # overridden.
+        if ( $self->theme ) {
+            my %theme_helpers = %{ $self->theme->_helpers };
+            for my $helper ( keys %theme_helpers ) {
+                *{"@{[$t->namespace]}::$helper"} = sub {
+                    $theme_helpers{ $helper }->( \%args, @_ );
+                };
+            }
+        }
+
+        # Add default helpers
         local *{"@{[$t->namespace]}::include"} = sub {
             my ( $name, %extra_args ) = @_;
             my $inner_tmpl = $self->theme->include( $name );
@@ -90,6 +103,11 @@ sub render {
             return $args{site}->markdown->markdown( $text );
         };
 
+        local *{"@{[$t->namespace]}::content"} = sub {
+            my ( $section ) = @_;
+            return $args{content};
+        };
+
         my $err = $t->compile;
         if ( $err ) {
             die "Error in template: " . $err;
@@ -139,7 +157,7 @@ Statocles::Template - A template object to pass around
 
 =head1 VERSION
 
-version 0.061
+version 0.062
 
 =head1 DESCRIPTION
 
@@ -206,6 +224,46 @@ be available as a simple scalar:
         ]
     );
 
+=head1 DEFAULT HELPERS
+
+The following functions are available to the template by default.
+
+=head2 content
+
+    %= content
+    <%= content %>
+
+Add the main content of the template. This will be the HTML from the document
+or page.
+
+=head2 include
+
+    %= include 'path/file.html.ep'
+    %= include 'path/file.markdown', var => 'value'
+
+Include a file into this one. The file will be parsed as a template and
+given the same variables as the current template. Optionally, additional
+name-value pairs can be given to the included template. These additional
+template variables override any current variables.
+
+Including markdown files does not automatically translate them into
+HTML. If you're in a page template or layout template, use the
+L<markdown helper|/markdown> to render the markdown into HTML.
+
+=head2 markdown
+
+    %= markdown $markdown_text
+    %= markdown $app->{data}{description}
+    %= markdown include 'path/include.markdown'
+
+Render the given markdown text into HTML. This is useful for allowing users to
+write markdown in L<site data|Statocles::Site/data>, and L<app data|Statocles::App/data> in
+the L<configuration file|Statocles::Help::Config/data>,
+or L<document data|Statocles::Document/data> attributes in the document frontmatter.
+
+Combining the C<markdown> and L<include|/include> helpers allows for adding
+template directives to any included markdown file.
+
 =head1 SEE ALSO
 
 =over 4
