@@ -1,6 +1,6 @@
 package Statocles::Theme;
 # ABSTRACT: Templates, headers, footers, and navigation
-$Statocles::Theme::VERSION = '0.061';
+$Statocles::Theme::VERSION = '0.062';
 use Statocles::Base 'Class';
 use File::Share qw( dist_dir );
 use Scalar::Util qw( blessed );
@@ -43,6 +43,14 @@ has _includes => (
     clearer => '_clear_includes',
 );
 
+# The helpers added to this theme.
+has _helpers => (
+    is => 'ro',
+    isa => HashRef[CodeRef],
+    default => sub { {} },
+    init_arg => 'helpers', # Allow initialization via config file
+);
+
 
 around BUILDARGS => sub {
     my ( $orig, $self, @args ) = @_;
@@ -106,6 +114,13 @@ sub include {
 }
 
 
+sub helper {
+    my ( $self, $name, $sub ) = @_;
+    $self->_helpers->{ $name } = $sub;
+    return;
+}
+
+
 sub clear {
     my ( $self ) = @_;
     $self->_clear_templates;
@@ -132,7 +147,7 @@ Statocles::Theme - Templates, headers, footers, and navigation
 
 =head1 VERSION
 
-version 0.061
+version 0.062
 
 =head1 SYNOPSIS
 
@@ -221,6 +236,14 @@ Get the desired L<template|Statocles::Template> to include based on the given
 C<path> or C<path_parts>. Looks through all the
 L<include_stores|/include_stores> before looking in the L<main store|/store>.
 
+=head2 helper
+
+    $theme->helper( $name, $sub );
+
+Register a helper on this theme. Helpers are functions that are added to
+the template to allow for additional features. Helpers are usually added
+by plugins.
+
 =head2 clear
 
     $theme->clear;
